R/before.R
before.RdCriterion constructor function to be combined in a custom search statement
before(date_char, negate = FALSE)A search string to be used as a request parameter in
ImapCon$search() function.
Other custom search:
AND(),
ImapCon,
OR(),
filter_stored(),
flag(),
fuzzy(),
larger_than(),
modseq(),
older_than(),
on(),
saved_before(),
sent_before(),
sent_on(),
sent_since(),
since(),
smaller_than(),
string(),
younger_than()
if (FALSE) { # \dontrun{
# select folder & search
con$select_folder(name = "INBOX")
# search for messages BEFORE "17-Apr-2019" AND NOT SMALLER than 512KB.
res <- con$search(request = AND(before(date_char = "17-Apr-2019"),
smaller_than(size = 512000, negate = TRUE)))
} # }