R/older-than.R
older_than.RdCriterion constructor function to be combined in a custom search statement
older_than(seconds, negate = FALSE)To be able to use this functionality, the server must support the
WITHIN capability.
Other custom search:
AND(),
ImapCon,
OR(),
before(),
flag(),
larger_than(),
modseq(),
on(),
saved_before(),
sent_before(),
sent_on(),
sent_since(),
since(),
smaller_than(),
string(),
younger_than()
if (FALSE) { # \dontrun{
# select folder & search
con$select_folder(name = "INBOX")
# search for messages containing the string "XYZ@k-state.edu" in the
# "FROM" field AND those that are OLDER than 3600 seconds (1 hour).
res <- con$search(request = AND(string(expr = "XYZ@k-state.edu",
where = "FROM"),
older_than(seconds = 3600)))
} # }