R/sent-before.R
sent_before.RdCriterion constructor function to be combined in a custom search statement
sent_before(date_char, negate = FALSE)A search string to be used as a request parameter in
ImapCon$search() function.
Other custom search:
AND(),
ImapCon,
OR(),
before(),
flag(),
larger_than(),
modseq(),
older_than(),
on(),
saved_before(),
sent_on(),
sent_since(),
since(),
smaller_than(),
string(),
younger_than()
if (FALSE) { # \dontrun{
# select folder & search
con$select_folder(name = "INBOX")
# search for messages SINCE "30-Aug-2019" AND SMALLER than 512KB.
res <- con$search(request = AND(sent_since(date_char = "30-Aug-2019"),
smaller_than(size = 512000)))
} # }