R/sent-on.R
sent_on.RdCriterion constructor function to be combined in a custom search statement
sent_on(date_char, negate = FALSE)A search string to be used as a request parameter in
ImapCon$search() function.
Other custom search:
AND(),
ImapCon,
OR(),
before(),
filter_stored(),
flag(),
fuzzy(),
larger_than(),
modseq(),
older_than(),
on(),
saved_before(),
sent_before(),
sent_since(),
since(),
smaller_than(),
string(),
younger_than()
if (FALSE) { # \dontrun{
# select folder & search
con$select_folder(name = "INBOX")
# search for messages SINCE "30-Aug-2019" OR LARGER than 512KB.
res <- con$search(request = OR(sent_since(date_char = "30-Jun-2020"),
larger_than(size = 512000)))
} # }