Skip to contents

Criterion constructor function to be combined in a custom search statement

Usage

younger_than(seconds, negate = FALSE)

Arguments

seconds

An integer specifying the number of seconds to be used as the search criterion.

negate

If TRUE, negates the search and seeks for "NOT SEARCH CRITERIA". Default is FALSE.

Value

A search criterion of class imap_search, to be combined into a search statement (see Ops.imap_search).

Note

To be able to use this functionality, the server must support the WITHIN capability.

Examples

if (FALSE) { # \dontrun{
# select folder & search
con$select_folder(folder = "INBOX")
# search for messages containing the string "XYZ@k-state.edu" in the
#   "FROM" field AND those that are YOUNGER than 3600 seconds (1 hour).
res <- con$search(request = AND(string(expr = "XYZ@k-state.edu",
                                      where = "FROM"),
                               younger_than(seconds = 3600)))
} # }