Criterion constructor function to be combined in a custom search statement
Source:R/larger-than.R
larger_than.RdCriterion constructor function to be combined in a custom search statement
Value
A search criterion of class imap_search, to be combined
into a search statement (see Ops.imap_search).
See also
Other custom search:
AND(),
ImapCon,
OR(),
before(),
filter_stored(),
flag(),
fuzzy(),
modseq(),
older_than(),
on(),
saved_before(),
sent_before(),
sent_on(),
sent_since(),
since(),
smaller_than(),
string(),
verbatim(),
younger_than()
Examples
if (FALSE) { # \dontrun{
# select folder & search
con$select_folder(folder = "INBOX")
# search for messages containing the string "XYZ@k-state.edu" in the
# "FROM" field OR those that are LARGER than 512KB.
res <- con$search(request = OR(string(expr = "XYZ@k-state.edu",
where = "FROM"),
larger_than(size = 512000)))
} # }