Builds the MODSEQ search key, which matches the messages whose
modification sequence is equal to or greater than value, i.e. the
messages that were added or whose flags changed since the folder had that
HIGHESTMODSEQ (obtained with ImapCon$status(items =
"HIGHESTMODSEQ")). It is to be combined with AND and
OR and passed to ImapCon$search(). The server must
advertise the CONDSTORE capability.
modseq(value, negate = FALSE)A character string with the search criterion.
Other custom search:
AND(),
ImapCon,
OR(),
before(),
flag(),
larger_than(),
older_than(),
on(),
saved_before(),
sent_before(),
sent_on(),
sent_since(),
since(),
smaller_than(),
string(),
younger_than()
if (FALSE) { # \dontrun{
con$select_folder(name = "INBOX")
last <- con$status(items = "HIGHESTMODSEQ")[["HIGHESTMODSEQ"]]
# ... later, in another run:
changed <- con$search(request = modseq(last + 1))
} # }