R/saved-date.R
saved_before.RdBuild the SAVEDBEFORE, SAVEDON, and SAVEDSINCE search
keys, which compare the date a message was saved into the mailbox (the
SAVEDATE attribute) rather than its internal date or its
Date: header. They are to be combined with AND and
OR and passed to ImapCon$search(). The server must
advertise the SAVEDATE capability.
saved_before(date_char, negate = FALSE)
saved_since(date_char, negate = FALSE)
saved_on(date_char, negate = FALSE)A character string with the search criterion.
Other custom search:
AND(),
ImapCon,
OR(),
before(),
flag(),
larger_than(),
modseq(),
older_than(),
on(),
sent_before(),
sent_on(),
sent_since(),
since(),
smaller_than(),
string(),
younger_than()
if (FALSE) { # \dontrun{
con$select_folder(name = "INBOX")
# messages saved into the folder during the last ingestion day
res <- con$search(request = saved_since(date_char = "27-Aug-2026"))
} # }