Criterion constructor function to be combined in a custom search statement
Source:R/younger-than.R
younger_than.RdCriterion constructor function to be combined in a custom search statement
Value
A search criterion of class imap_search, to be combined
into a search statement (see Ops.imap_search).
See also
Other custom search:
AND(),
ImapCon,
OR(),
before(),
filter_stored(),
flag(),
fuzzy(),
larger_than(),
modseq(),
older_than(),
on(),
saved_before(),
sent_before(),
sent_on(),
sent_since(),
since(),
smaller_than(),
string(),
verbatim()
Examples
if (FALSE) { # \dontrun{
# select folder & search
con$select_folder(folder = "INBOX")
# search for messages containing the string "XYZ@k-state.edu" in the
# "FROM" field AND those that are YOUNGER than 3600 seconds (1 hour).
res <- con$search(request = AND(string(expr = "XYZ@k-state.edu",
where = "FROM"),
younger_than(seconds = 3600)))
} # }